@@ -2293,51 +2293,91 @@ var require_subset = __commonJS({
 var require_semver2 = __commonJS({
   "node_modules/semver/index.js"(exports, module2) {
     var internalRe = require_re();
+    var constants = require_constants();
+    var SemVer = require_semver();
+    var identifiers = require_identifiers();
+    var parse = require_parse();
+    var valid = require_valid();
+    var clean = require_clean();
+    var inc2 = require_inc();
+    var diff = require_diff();
+    var major = require_major();
+    var minor = require_minor();
+    var patch = require_patch();
+    var prerelease = require_prerelease();
+    var compare = require_compare();
+    var rcompare = require_rcompare();
+    var compareLoose = require_compare_loose();
+    var compareBuild = require_compare_build();
+    var sort = require_sort();
+    var rsort = require_rsort();
+    var gt = require_gt();
+    var lt = require_lt();
+    var eq = require_eq();
+    var neq = require_neq();
+    var gte = require_gte();
+    var lte = require_lte();
+    var cmp = require_cmp();
+    var coerce = require_coerce();
+    var Comparator = require_comparator();
+    var Range = require_range();
+    var satisfies = require_satisfies();
+    var toComparators = require_to_comparators();
+    var maxSatisfying2 = require_max_satisfying();
+    var minSatisfying = require_min_satisfying();
+    var minVersion = require_min_version();
+    var validRange = require_valid2();
+    var outside = require_outside();
+    var gtr = require_gtr();
+    var ltr = require_ltr();
+    var intersects = require_intersects();
+    var simplifyRange = require_simplify();
+    var subset = require_subset();
     module2.exports = {
+      parse,
+      valid,
+      clean,
+      inc: inc2,
+      diff,
+      major,
+      minor,
+      patch,
+      prerelease,
+      compare,
+      rcompare,
+      compareLoose,
+      compareBuild,
+      sort,
+      rsort,
+      gt,
+      lt,
+      eq,
+      neq,
+      gte,
+      lte,
+      cmp,
+      coerce,
+      Comparator,
+      Range,
+      satisfies,
+      toComparators,
+      maxSatisfying: maxSatisfying2,
+      minSatisfying,
+      minVersion,
+      validRange,
+      outside,
+      gtr,
+      ltr,
+      intersects,
+      simplifyRange,
+      subset,
+      SemVer,
       re: internalRe.re,
       src: internalRe.src,
       tokens: internalRe.t,
-      SEMVER_SPEC_VERSION: require_constants().SEMVER_SPEC_VERSION,
-      SemVer: require_semver(),
-      compareIdentifiers: require_identifiers().compareIdentifiers,
-      rcompareIdentifiers: require_identifiers().rcompareIdentifiers,
-      parse: require_parse(),
-      valid: require_valid(),
-      clean: require_clean(),
-      inc: require_inc(),
-      diff: require_diff(),
-      major: require_major(),
-      minor: require_minor(),
-      patch: require_patch(),
-      prerelease: require_prerelease(),
-      compare: require_compare(),
-      rcompare: require_rcompare(),
-      compareLoose: require_compare_loose(),
-      compareBuild: require_compare_build(),
-      sort: require_sort(),
-      rsort: require_rsort(),
-      gt: require_gt(),
-      lt: require_lt(),
-      eq: require_eq(),
-      neq: require_neq(),
-      gte: require_gte(),
-      lte: require_lte(),
-      cmp: require_cmp(),
-      coerce: require_coerce(),
-      Comparator: require_comparator(),
-      Range: require_range(),
-      satisfies: require_satisfies(),
-      toComparators: require_to_comparators(),
-      maxSatisfying: require_max_satisfying(),
-      minSatisfying: require_min_satisfying(),
-      minVersion: require_min_version(),
-      validRange: require_valid2(),
-      outside: require_outside(),
-      gtr: require_gtr(),
-      ltr: require_ltr(),
-      intersects: require_intersects(),
-      simplifyRange: require_simplify(),
-      subset: require_subset()
+      SEMVER_SPEC_VERSION: constants.SEMVER_SPEC_VERSION,
+      compareIdentifiers: identifiers.compareIdentifiers,
+      rcompareIdentifiers: identifiers.rcompareIdentifiers
     };
   }
 });
